==> paxo-0.1.1.tar.gz: paxo-0.1.1/README.md <==
# paxo: python ♡ terminal

[`paxo`](https://github.com/cwoebker/paxo) is a small library that makes it fast and easy to create simple python command line tools.

[![Status unavailable](https://secure.travis-ci.org/cwoebker/paxo.png?branch=master)](http://travis-ci.org/cwoebker/paxo)

---

## What is this? ##

With `paxo` you can quickly create terminal applications with python.
It handles a bunch of stuff in the background so that you do not need to worry about it.

Why **Yet Another Command Line Library**?

Well, for me paxo is not just a command line library managing your arguments and options but also managing everything related to those commands. It generates a quick info view of your commands and also provides a help command to learn more about each command.
I hope that in the Future it will be able to handle everything documentation, manage all application configuration and data and be fully customizable so that you can create your own themes for a terminal app.
If you just want a simple library to take care for shell arguments for you there are many other options available to you.

![Paxo Terminal](http://cwoebker.com/assets/img/posts/paxo.jpg)

## Installation ##

It's as simple as:

`$ pip install paxo`

## Usage ##

Paxo is really easy to use for anyone, whether you want to start quickly or customize your command line application to your own needs entirely. You can see `paxo` in action with some of my side projects. (e.g. [pen](http://github.com/cwoebker/pen) or [como](http://github.com/cwoebker/como)).
You can find a [minimalistic script](http://github.com/cwoebker/paxo) that makes use of this library inside the project's example folder:

    from paxo import Paxo
    from paxo.command import cmd


    @cmd(help='Print out a help message.')
    def hello(args):
        print 'Hello World!'

    app = Paxo('example', 'a Cecil Woebker project.', '<command>', '0.1')

    if __name__ == '__main__':
        app.go()

A simple command line call `./example.py hello` prints “Hello World!“. Take a look at the above screenshot for the accompanying info screen of the example.py command.

## Advanced ##

If you want to know even more make sure to check out the source code or look at some of the projects I mentioned above.
## Features ##

- Mange commands, usage and help information
- Easily map commands to python functions
- Declare a default action
- Declare a dynamic action

## TODO

- Additional decorator for dynamic/default action
- Route shell arguments to python functions automatically
- Automatically create usage text from function signature
- Cleanup Command management
- Manage app configuration
- Manage app data
- Loose dependencies and become standalone
- Support for command line options (ala `-o, `-a`, `-u`)
- Extended documentation feature - Create man pages
- Cross Platform support
    - Additional decorator for OS support
- Create sphinx documentation for “paxo“
- Themes for “paxo“ - Design your own command line tool

## Contribute ##

**Beware:** I developed this mainly for my own projects. Unfortunately this tool is not yet as versatile as I would like
it to be. If you have any questions or would like some new features please let me know!

[Fork and contribute!](http://github.com/cwoebker/paxo)

---

For questions and suggestions, feel free to shoot me an email <me@cwoebker.com>

Follow [@cwoebker](http://twitter.com/cwoebker)

---

Copyright (c) 2015, Cecil Woebker.
License: BSD (see LICENSE for details)

==> paxo-0.3.0.tar.gz: paxo-0.3.0/README.md <==
# paxo: python ♡ terminal

[`paxo`](https://github.com/cwoebker/paxo) is a small library that makes it fast and easy to create simple python command line tools.

[![PyPI Version](https://img.shields.io/pypi/v/paxo.svg)](https://pypi.python.org/pypi/paxo)
[![Build Status](https://secure.travis-ci.org/cwoebker/paxo.png?branch=master)](http://travis-ci.org/cwoebker/paxo)
[![PyPI License](https://img.shields.io/pypi/l/paxo.svg)](https://pypi.python.org/pypi/paxo)
[![PyPI Python Versions](https://img.shields.io/pypi/pyversions/paxo.svg)](https://pypi.python.org/pypi/paxo)
[![Say Thanks!](https://img.shields.io/badge/Say%20Thanks-!-1EAEDB.svg)](https://saythanks.io/to/cwoebker)

---

## What is this? ##

With `paxo` you can quickly create terminal applications with python.
It handles a bunch of stuff in the background so that you do not need to worry about it.

Why **Yet Another Command Line Library**?

Well, for me paxo is not just a command line library managing your arguments and options but also managing everything related to those commands. It generates a quick info view of your commands and also provides a help command to learn more about each command.
I hope that in the Future it will be able to handle everything documentation, manage all application configuration and data and be fully customizable so that you can create your own themes for a terminal app.
If you just want a simple library to take care for shell arguments for you there are many other options available to you.

![Paxo Terminal](https://cwoebker.com/assets/img/posts/paxo.jpg)

## Installation ##

It's as simple as:

`$ pip install paxo`

## Usage ##

Paxo is really easy to use for anyone, whether you want to start quickly or customize your command line application to your own needs entirely. You can see `paxo` in action with some of my side projects. (e.g. [pen](https://github.com/cwoebker/pen) or [como](https://github.com/cwoebker/como)).
You can find a [minimalistic script](https://github.com/cwoebker/paxo) that makes use of this library inside the project's example folder:

    from paxo import Paxo
    from paxo.command import cmd


    @cmd(help='Print out a help message.')
    def hello(args):
        print 'Hello World!'

    app = Paxo('example', 'a Cecil Woebker project.', '<command>', '0.1')

    if __name__ == '__main__':
        app.go()

A simple command line call `./example.py hello` prints “Hello World!“. Take a look at the above screenshot for the accompanying info screen of the example.py command.

## Advanced ##

If you want to know even more make sure to check out the source code or look at some of the projects I mentioned above.
## Features ##

- Mange commands, usage and help information
- Easily map commands to python functions
- Declare a default action
- Declare a dynamic action

## TODO

- Additional decorator for dynamic/default action
- Route shell arguments to python functions automatically
- Automatically create usage text from function signature
- Cleanup Command management
- Manage app configuration
- Manage app data
- Loose dependencies and become standalone
- Support for command line options (ala `-o`, `-a`, `-u`)
- Extended documentation feature - Create man pages
- Cross Platform support
    - Additional decorator for OS support
- Create sphinx documentation for “paxo“
- Themes for “paxo“ - Design your own command line tool

## Contribute ##

**Beware:** I developed this mainly for my own projects. Unfortunately this tool is not yet as versatile as I would like
it to be. If you have any questions or would like some new features please let me know!

[Fork and contribute!](http://github.com/cwoebker/paxo)

---

For questions and suggestions, feel free to shoot me an email at <me@cwoebker.com>.

Also, follow or tweet [@cwoebker](https://twitter.com/cwoebker).

---

Copyright (c) 2015-2018, Cecil Wöbker.
License: BSD (see LICENSE for details)
